@@ -33,7 +33,7 @@ class Broker:
         # Assign broker utilities
         if utils is None:
             utils = BrokerUtils()
-        self.utils = utils
+        self._utils = utils
 
         # Create AutoData instance
         data_config = utilities.get_data_config(feed="oanda")
@@ -314,7 +314,7 @@ class Broker:
         response = self.api.instrument.candles(
             pair, granularity=interval, count=period, dailyAlignment=0
         )
-        data = self.utils.response_to_df(response)
+        data = self._utils.response_to_df(response)
         return data
 
     def check_trade_size(self, instrument: str, units: float) -> float:
@@ -389,7 +389,7 @@ class Broker:
             instrument, granularity=interval, fromTime=from_time, toTime=to_time
         )
 
-        data = self.utils.response_to_df(response)
+        data = self._utils.response_to_df(response)
 
         return data
 
