@@ -65,6 +65,9 @@ class Order:
         is '0.015'.
     exchange : str
         The exchange to which the order should be submitted.
+    ccxt_params : dict, optional
+        The CCXT parameters dictionary to pass when creating an order. The
+        default is {}.
     """
 
     def __init__(
@@ -130,6 +133,9 @@ class Order:
         self.post_only = False
         self.limit_fee = "0.015"
 
+        # CCXT attributes
+        self.ccxt_params = {}
+
         self.reason = None
 
         self.strategy = None
@@ -374,21 +380,31 @@ class Order:
                 self.size = round(self.base_size / HCF, self.size_precision)
             else:
                 # Size not provided, need to calculate it
-                amount_risked = (
-                    amount_risked if amount_risked else broker.get_NAV() * risk_pc / 100
-                )
-
                 if sizing == "risk":
                     # Calculate size from SL placement
-                    size = broker._utils.get_size(
-                        instrument=self.instrument,
-                        amount_risked=amount_risked,
-                        price=working_price,
-                        HCF=HCF,
-                        stop_price=self.stop_loss,
-                        stop_distance=self.stop_distance,
-                    )
-                    self.size = round(size, self.size_precision)
+                    try:
+                        amount_risked = (
+                            amount_risked
+                            if amount_risked
+                            else broker.get_NAV() * risk_pc / 100
+                        )
+
+                        size = broker._utils.get_size(
+                            instrument=self.instrument,
+                            amount_risked=amount_risked,
+                            price=working_price,
+                            HCF=HCF,
+                            stop_price=self.stop_loss,
+                            stop_distance=self.stop_distance,
+                        )
+                        self.size = round(size, self.size_precision)
+
+                    except AttributeError:
+                        # Broker is None type
+                        raise Exception(
+                            "Cannot calculate size without broker access. Please "
+                            + "pass size argument, or add broker to Order object."
+                        )
 
                 else:
                     # Use position size provided via sizing key
@@ -674,6 +690,8 @@ class Position:
     ----------
     instrument : str
         The trade instrument of the position.
+    pnl : float
+        The pnl of the position.
     long_units : float
         The number of long units in the position.
     long_PL : float
@@ -704,6 +722,7 @@ class Position:
 
     def __init__(self, **kwargs):
         self.instrument = None
+        self.pnl = None
         self.long_units = None
         self.long_PL = None
         self.long_margin = None
@@ -723,6 +742,9 @@ class Position:
         # dYdX Attributes
         self.entry_price = None
 
+        # CCXT Attributes
+        self.ccxt = None
+
         for item in kwargs:
             setattr(self, item, kwargs[item])
 
